/*
** Module   : Content.java
** Abstract : Progress 4GL INI flie content abstract class.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130701 Created initial version
*/

package com.goldencode.p2j.util;

import java.io.*;

/**
 * Abstract class implementing the INI text file content. Can be either line to ignore in the
 * case of comment or empty line or key=value section with possible comments or empty lines.
 *
 * @author    EVL
 */
public abstract class Content
{
   /** Extra urecognized data in INI file. This should be string never used for real key. */
   public static final String KEY_INRECOGNIZED_MARK = "----";
   
   /** The name associated with the content. Either section name or just single line. */
   protected String name = null;
   
   /**
    * Constructs an instance of the simple line in INI file.
    *
    * @param name 
    *        The name of the content corresponding to the whole line of the comment or empty
    *        space line.
    */
   public Content(String name)
   {
      this.name = name;
   }
   
   /**
    * Checks if the content's name equals to the given name.
    * 
    * @param name 
    *        The name to compare with internal content name.
    * 
    * @return <code>true</code> in case of success, <code>false</code> otherwise.
    */
   public boolean withName(String name)
   {
      return this.name.equals(name);
   }
   
   /**
    * Writes the content to the file via Writer object provided.
    * 
    * @param pw 
    *        The writer will be used to save content to the file.
    */
   public abstract void writeToFile(PrintWriter pw);
   
   /**
    * Checks if the content is empty or not.
    * 
    * @return <code>true</code> in case of not emptry, <code>false</code> otherwise.
    */
   public abstract boolean notEmpty();
}
